<?php
// ---------------------------------------------------------------------------
// $Id: File.class.php,v 1.2 2004/05/02 14:41:31 dankert Exp $
// ---------------------------------------------------------------------------
// DaCMS Content Management System
// Copyright (C) 2002 Jan Dankert, jandankert@jandankert.de
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
// ---------------------------------------------------------------------------
// $Log: File.class.php,v $
// Revision 1.2  2004/05/02 14:41:31  dankert
// Einfgen package-name (@package)
//
// Revision 1.1  2004/04/24 15:15:12  dankert
// Initiale Version
//
// Revision 1.1  2003/10/27 23:21:55  dankert
// Methode(n) hinzugefgt: savevalue(), save()
//
// ---------------------------------------------------------------------------


/**
 * Darstellen einer Datei
 *
 * @version $Revision: 1.2 $
 * @author $Author: dankert $
 * @package openrat.objects
 */
class File extends Object
{
	var $fileid;

	var $size  = 0;
	var $value = '';
	var $extension     = '';
	var $log_filenames = array();
	var $publish = null;
	
	/**
	 * Um Probleme mit BLOB-Feldern und Datenbank-Besonderheiten zu vermeiden,
	 * kann der Binrinhalt BASE64-kodiert gespeichert werden.
	 * @type Boolean
	 */
	var $storeValueAsBase64 = false;

	function File( $objectid='' )
	{
		global $conf,$SESS;
		
		if	( isset($conf['database_'.$SESS['dbid']]['base64']) &&
		       $conf['database_'.$SESS['dbid']]['base64'] == true )
			$this->storeValueAsBase64 = true;
		else	$this->storeValueAsBase64 = false;

		$this->Object( $objectid );
		$this->isFile = true;
	}


	/**
	  * Ermitteln des Dateinamens dieser Datei
	  *
	  * @return String Kompletter Dateiname, z.B. '/pfad/datei.jpeg'
	  */
	function full_filename()
	{
		$filename = parent::full_filename();

		if	( $this->extension != '' )
		{
			$filename .= '.'.$this->extension;
		}

		return $filename;
	}


	/**
	  * Ermitteln des Dateinamens dieser Datei (ohne Pfadangabe)
	  *
	  * @return String Kompletter Dateiname, z.B. '/pfad/datei.jpeg'
	  */
	function filenameWithExtension()
	{
		if	( $this->extension != '' )
			return $this->filename.'.'.$this->extension;
		else	return $this->filename;
	}


	/**
	  * Ermitteln aller Eigenschaften
	  *
	  * @return Array
	  */
	function getProperties()
	{
		return array_merge( parent::getProperties(),
		                    Array('full_filename'=>$this->full_filename(),
		                          'extension'    =>$this->extension,
		                          'size'         =>$this->size,
		                          'mimetype'     =>$this->mimetype()   ) );
	}


	function getFileObjectIdsByExtension( $extension )
	{
		global $SESS;
		$db = db_connection();
		
		$sqlquery = 'SELECT * FROM {t_object} ';

		if   ( $extension != '' )
		{
			$sqlquery .= " WHERE extension='";

			$ext = explode(',',$extension);
			$sqlquery .= implode( "' OR extension='",$ext );
			$sqlquery .= "' AND is_file=1 AND projectid={projectid}";
		}
		else
		{
			$sqlquery .= " WHERE is_file=1 AND projectid={projectid}";
		}

		$sql = new Sql( $sqlquery );
		$sql->setInt( 'projectid',$SESS['projectid'] );
		
		return $db->getCol( $sql->query );
	}


	/**
	  * Es werden Objekte zu einer Dateierweiterung ermittelt
	  * @param String Dateierweiterung ohne fhrenden Punkt (z.B. 'jpeg')
	  * @return Array Liste der gefundenen Objekt-IDs
	  */
	function getObjectIdsByExtension( $extension )
	{
		$db = db_connection();
		
		$sql = new Sql( 'SELECT {t_file}.objectid FROM {t_file} '.
		                ' LEFT JOIN {t_object} '.
		                '   ON {t_object}.id={t_file}.objectid'.
		                ' WHERE {t_file}.extension={extension}'.
		                '   AND {t_object}.projectid={projectid}' );
		$sql->setInt   ( 'projectid',$this->projectid );
		$sql->setString( 'extension',$extension       );
		
		return $db->getCol( $sql->query );
	}


	function mimeType()
	{
		global $conf_languagedir,$conf_php;
		$mime_types = parse_ini_file( "$conf_languagedir/mime-types.ini.$conf_php" );

		if	( isset($mime_types[ strtolower($this->extension) ]) )
			$mime = $mime_types[ strtolower($this->extension) ];
		else	$mime = 'application/octet-stream';
			
		return( $mime );
	}


	function imageResize( $newWidth,$newHeight )
	{
		global $conf;

		// Schalter, ob GD in Version 2 verfuegbar ist
		$gd2 = $conf['gd']['version2'];
		
		$this->write(); // Datei schreiben
		
		// Bildinformationen ermitteln
		$size = getimagesize( $this->tmpfile() );

		// Breite und Hoehe des aktuellen Bildes	 
		$oldWidth  = $size[0]; 
		$oldHeight = $size[1];
		$aspectRatio = $oldHeight / $oldWidth; // Seitenverhaeltnis

		// Wenn nur Breite oder Hoehe angegeben ist, dann
		// das Seitenverhaeltnis beibehalten
		if	( $newWidth == 0 )
			$newWidth = $newHeight / $aspectRatio; 
		
		if	( $newHeight == 0 )
			$newHeight = $newWidth * $aspectRatio; 

		switch( $size[2] )
		{
			case '1': // GIF

				$oldImage = ImageCreateFromGIF( $this->tmpfile ); 
				$newImage = ImageCreate($newWidth,$newHeight); 
				ImageCopyResized($newImage,$oldImage,0,0,0,0,$newWidth,
					$newHeight,$oldWidth,$oldHeight); 
				ImageGIF($newImage, $this->tmpfile() ); 
				$this->extension = 'gif';

				break;

			case '2': // JPEG

				$oldImage = ImageCreateFromJPEG($this->tmpfile);
	
				if   ( $gd2 )
				{
					// Verwende TrueColor
					$newImage = imageCreateTrueColor( $newWidth,$newHeight );
	
					ImageCopyResampled($newImage,$oldImage,0,0,0,0,$newWidth,
					$newHeight,$oldWidth,$oldHeight);
				}
				else
				{
					// GD Version 1.x untersttzt kein TrueColor
					$newImage = ImageCreate($newWidth,$newHeight);
	
					ImageCopyResized($newImage,$oldImage,0,0,0,0,$newWidth,
					$newHeight,$oldWidth,$oldHeight);
				}
	
				ImageJPEG($newImage, $this->tmpfile ); 
				$this->extension = 'jpeg';

				break;

			case '3': // PNG

				$oldImage = imagecreatefrompng($this->tmpfile);
				if   ( $gd2 )
				{
					// Verwende TrueColor
					$newImage = imageCreateTrueColor( $newWidth,$newHeight );
		
					ImageCopyResampled($newImage,$oldImage,0,0,0,0,$newWidth,
					$newHeight,$oldWidth,$oldHeight); 
				}
				else
				{
					// GD Version 1.x untersttzt kein TrueColor
					$newImage = ImageCreate($newWidth,$newHeight);
		
					ImageCopyResized($newImage,$oldImage,0,0,0,0,$newWidth,
					$newHeight,$oldWidth,$oldHeight); 
				}
		
				imagepng( $newImage,$this->tmpfile() );
				$this->extension = 'png';
				
				break;
				
			default:
				die('unsupported type for resizing');
		} 

		$f = fopen( $this->tmpfile(), "r" );
		$this->value = fread( $f,filesize($this->tmpfile()) );
		fclose( $f );
	}


	// Lesen der Datei aus der Datenbank
	function load()
	{
		$db = db_connection();

		$sql = new Sql( 'SELECT id,extension,size'.
		                ' FROM {t_file}'.
		                ' WHERE objectid={objectid}' );
		$sql->setInt( 'objectid',$this->objectid );
		$row = $db->getRow( $sql->query );

		$this->fileid    = $row['id'       ];
		$this->extension = $row['extension'];
		$this->size      = $row['size'     ];
		
		$this->objectLoad();
	}



	function delete()
	{
		$db = db_connection();

		// Datei lschen
		$sql = new Sql( 'DELETE FROM {t_file} '.
		                '  WHERE objectid={objectid}' );
		$sql->setInt( 'objectid',$this->objectid );
		$db->query( $sql->query );
		
		$this->objectDelete();
	}


	/**
	 * Stellt fest, ob es sich bei dieser Datei um ein Bild handelt
	 */
	function isImage()
	{
		return eregi('jpe?g|png|gif',$this->extension);
	}


	function extension()
	{
		if ($this->extension != '')
			return $this->extension;

		$this->load();
		return $this->extension;
	}


	// Einen Dateinamen in Dateiname und Extension aufteilen
	function parse_filename($filename)
	{
		$filename = basename($filename);

		$p = strrpos($filename, '.');
		if ($p !== false)
		{
			$this->extension = substr($filename, $p +1);
			$this->filename = substr($filename, 0, $p);
		}
		else
		{
			$this->extension = '';
			$this->filename = $filename;
		}
	}


	function save()
	{
		global $SESS;
		$db = db_connection();
		
		$sql = new Sql('UPDATE {t_file} SET '.
		               '  size      = {size},'.
		               '  extension = {extension}'.
		               ' WHERE objectid={objectid}' );
		$sql->setString('size'     ,$this->size      );
		$sql->setString('extension',$this->extension );
		$sql->setString('objectid' ,$this->objectid  );
		$db->query( $sql->query );
		
		$this->objectSave();
	}


	// Lesen der Datei aus der Datenbank
	function loadValue()
	{
		$db = db_connection();

		$sql = new Sql( 'SELECT size,value'.
		                ' FROM {t_file}'.
		                ' WHERE objectid={objectid}' );
		$sql->setInt( 'objectid',$this->objectid );
		$row = $db->getRow( $sql->query );
		
		$this->value = $row['value'];
		$this->size  = $row['size' ];

		if	( $this->storeValueAsBase64 )
			$this->value = base64_decode( $this->value );
		
		return( $this->value );
	}


	// Lesen der Datei aus der Datenbank
	function saveValue( $value = '' )
	{
		$db = db_connection();

		$sql = new Sql( 'UPDATE {t_file}'.
		                ' SET value={value}, '.
		                '      size={size}   '.
		                ' WHERE objectid={objectid}' );
		$sql->setString( 'objectid' ,$this->objectid      );
		$sql->setInt   ( 'size'     ,strlen($this->value) );
		
		if	( $this->storeValueAsBase64 )
			$sql->setString( 'value'    ,base64_encode($this->value) );
		else $sql->setString( 'value'    ,$this->value );

		$db->query( $sql->query );
	}


	// Lesen der Datei aus der Datenbank und schreiben in temporaere Datei
	function write()
	{
		$f = fopen( $this->tmpfile(),'w' );
		fwrite( $f,$this->loadValue() );
		fclose( $f );
	}


	function add()
	{
		$db = db_connection();

		$this->objectAdd();
		
		$sql = new Sql('SELECT MAX(id) FROM {t_file}');
		$this->fileid = intval($db->getOne($sql->query))+1;

		$sql = new Sql('INSERT INTO {t_file}'.
		               ' (id,objectid,extension,size,value)'.
		               " VALUES( {fileid},{objectid},{extension},0,'' )" );
		$sql->setInt   ('fileid'   ,$this->fileid        );
		$sql->setInt   ('objectid' ,$this->objectid      );
		$sql->setString('extension',$this->extension     );

		$db->query( $sql->query );
		
		$this->saveValue();
	}	


	function publish()
	{
		if	( ! is_object($this->publish) )
			$this->publish = new Publish();

		$this->write();
		$this->publish->copy( $this->tmpfile(),$this->full_filename() );

//		$this->log_filenames = $this->publish->log_filenames;
	}
}

?>