<?php
// ---------------------------------------------------------------------------
// $Id: Language.class.php,v 1.2 2004/05/02 14:41:31 dankert Exp $
// ---------------------------------------------------------------------------
// OpenRat Content Management System
// Copyright (C) 2002-2004 Jan Dankert, jandankert@jandankert.de
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
// ---------------------------------------------------------------------------
// $Log: Language.class.php,v $
// Revision 1.2  2004/05/02 14:41:31  dankert
// Einfgen package-name (@package)
//
// ---------------------------------------------------------------------------


/**
 * Darstellen einer Sprache. Jeder Seiteninhalt wird einer Sprache zugeordnet.
 *
 * @version $Revision: 1.2 $
 * @author $Author: dankert $
 * @package openrat.objects
 */
class Language
{
	var $languageid = 0;
	var $error      = '';
	var $projectid;

	var $name      = '';
	var $isoCode   = '';
	var $isDefault = false;


	// Konstruktor
	function Language( $languageid='' )
	{
		global $SESS;

		if   ( is_numeric($languageid) )
			$this->languageid = $languageid;

		$this->projectid = $SESS['projectid'];
	}


	// Lesen aller Sprachen aus der Datenbank
	function getAll()
	{
		global $SESS;
		$db = db_connection();

		$sql = new Sql( "SELECT id,name FROM {t_language} ".
		                "   WHERE projectid = {projectid} ".
		                "   ORDER BY name" );

		if	( isset($this->projectid) )
			$sql->setInt('projectid',$this->projectid );
		else	$sql->setInt('projectid',$SESS['projectid'] );

		return $db->getAssoc( $sql->query );
	}


	// Lesen aus der Datenbank
	function load()
	{
		$db = db_connection();

		$sql = new Sql( 'SELECT * FROM {t_language}'.
		                ' WHERE id={languageid}' );
		$sql->setInt( 'languageid',$this->languageid );

		$row = $db->getRow( $sql->query );

		$this->name     = $row['name'];
		$this->isoCode  = $row['isocode'];
		if	( $row['is_default'] == '1' )
			$this->isDefault = true;
		else $this->isDefault = false;
	}


	// Speichern der Sprache in der Datenbank
	function save()
	{
		$db = db_connection();

		// Gruppe speichern		
		$sql = new Sql( 'UPDATE {t_language} '.
		                'SET name      = {name}, '.
		                '    isocode   = {isocode} '.
		                'WHERE id={languageid}' );
		$sql->setString( 'name'     ,$this->name    );
		$sql->setString( 'isocode'  ,$this->isoCode );

		$sql->setInt( 'languageid',$this->languageid );

		// Datenbankabfrage ausfuehren
		$db->query( $sql->query );
	}


	/**
	 * Ermitteln aller Eigenschaften dieser Sprache
	 * @return Array
	 */
	function getProperties()
	{
		return Array( 'name'   =>$this->name,
		              'isocode'=>$this->isoCode );
	}


	/**
	 * Neue Sprache hinzufgen
	 */
	function add( $isocode='' )
	{
		global $SESS;
		global $iso;
		$db = db_connection();

		if	( $isocode != '' )
		{
			// Kleiner Trick, damit "no" (Norwegen) in der .ini-Datei stehen kann
			$isocode = str_replace('_','',$isocode);
			
			$this->isocode = $isocode;
			$codes = GlobalFunctions::getIsoCodes();
			$this->name    = $codes[ $isocode ];
		}

		$sql = new Sql('SELECT MAX(id) FROM {t_language}');
		$this->languageid = intval($db->getOne($sql->query))+1;

		// Sprache hinzufgen
		$sql = new Sql( 'INSERT INTO {t_language} '.
		                '(id,projectid,name,isocode,is_default) VALUES( {languageid},{projectid},{name},{isocode},0 )');
		$sql->setInt   ('languageid',$this->languageid );
		$sql->setInt   ('projectid' ,$this->projectid  );
		$sql->setString('name'      ,$this->name       );
		$sql->setString('isocode'   ,$this->isoCode    );

		// Datenbankbefehl ausfuehren
		$db->query( $sql->query );
	}


	// Diese Sprache als 'default' markieren.
	function setDefault()
	{
		global $SESS;
		$db = db_connection();

		// Zuerst alle auf nicht-Standard setzen
		$sql = new Sql( 'UPDATE {t_language} '.
		                '  SET is_default = 0 '.
		                '  WHERE projectid={projectid}' );
		$sql->setInt('projectid',$SESS['projectid'] );
		$db->query( $sql->query );
	
		// Jetzt die gewnschte Sprachvariante auf Standard setzen
		$sql = new Sql( 'UPDATE {t_language} '.
		                '  SET is_default = 1 '.
		                '  WHERE id={languageid}' );
		$sql->setInt('languageid',$this->languageid );
		$db->query( $sql->query );
	}


	function getDefaultId()
	{
		global $SESS;
		$db = db_connection();

		$sql = new Sql( 'SELECT id FROM {t_language} '.
		                '  WHERE projectid={projectid}'.
		                '   ORDER BY is_default DESC' );

		if	( isset($this->projectid) )
			$sql->setInt('projectid',$this->projectid );
		else	$sql->setInt('projectid',$SESS['projectid'] );
		
		return $db->getOne( $sql->query );
	}


	// Sprache entfernen
	function delete()
	{
		$db = db_connection();

		// Sprache lschen
//		$sql = new Sql( 'SELECT COUNT(*) FROM {t_language} WHERE projectid={projectid}' );
//		$sql->setInt( 'projectid',$this->projectid );
//		$count = $db->getOne( $sql->query );
//		
//		// Nur lschen, wenn es mindestens 2 Sprachen gibt
//		if   ( $count >= 2 )
//		{
			// Inhalte mit dieser Sprache lschen
			$sql = new Sql( 'DELETE FROM {t_value} WHERE languageid={languageid}' );
			$sql->setInt( 'languageid',$this->languageid );
			$db->query( $sql->query );

			// Inhalte mit dieser Sprache lschen
			$sql = new Sql( 'DELETE FROM {t_name} WHERE languageid={languageid}' );
			$sql->setInt( 'languageid',$this->languageid );
			$db->query( $sql->query );

			// Sprache lschen
			$sql = new Sql( 'DELETE FROM {t_language} WHERE id={languageid}' );
			$sql->setInt( 'languageid',$this->languageid );
			$db->query( $sql->query );

			// Andere Sprache auf "Default" setzen
			$sql = new Sql( 'SELECT id FROM {t_language} WHERE projectid={projectid}' );
			$sql->setInt( 'projectid',$this->projectid );
			$new_default_languageid = $db->getOne( $sql->query );

			$sql = new Sql( 'UPDATE {t_language} SET is_default=1 WHERE id={languageid}' );
			$sql->setInt( 'languageid',$new_default_languageid );
			$db->query( $sql->query );
//		}
	}
}

?>